pub struct CleanLine {
pub text: String,
pub spans: Vec<StyledSpan>,
}Expand description
One line with every escape sequence removed, plus the spans that describe what colour the surviving bytes were.
Fields
text: Stringspans: Vec<StyledSpan>Trait Implementations
impl Eq for CleanLine
impl StructuralPartialEq for CleanLine